==> react-native-wonder-amap-0.0.31.tgz: package/lib/ios/AMapEventEmitter.m <==
//
//  AMapEventDelegation.m
//  RCTAMap
//
//  Created by 王继荣 on 07/08/2017.
//  Copyright © 2017 cn.wonderbear. All rights reserved.
//

#import "AMapEventEmitter.h"

@interface AMapEventEmitter ()
{
    bool hasListeners;
}

@end

static AMapEventEmitter *sharedInstance;

@implementation AMapEventEmitter

RCT_EXPORT_MODULE()

+ (id)allocWithZone:(struct _NSZone *)zone
{
    static dispatch_once_t onceToken;
    dispatch_once(&onceToken, ^{
        sharedInstance = [super allocWithZone:zone];
    });
    return sharedInstance;
}

+ (instancetype)sharedInstance
{
    static dispatch_once_t onceToken;
    dispatch_once(&onceToken, ^{
        sharedInstance = [self new];
    });
    return sharedInstance;
}

- (id)copyWithZone:(NSZone *)zone
{
    return sharedInstance;
}

#pragma mark - RCTEventEmitter

- (NSArray<NSString *> *)supportedEvents
{
    return @[@"EventAnnotationSelect", @"EventAnnotationDeselect"];
}

- (void)startObserving {
    hasListeners = YES;
}

- (void)stopObserving {
    hasListeners = NO;
}

#pragma mark - MAMapViewDelegate

- (MAAnnotationView *)mapView:(MAMapView *)mapView viewForAnnotation:(id<MAAnnotation>)annotation
{
    if ([annotation isKindOfClass:[AMapAnnotation class]]) {
        MAAnnotationView *annotationView = (MAAnnotationView*)[mapView dequeueReusableAnnotationViewWithIdentifier:@"CustomAnnotationView"];
        if (!annotationView){
            annotationView = [[MAAnnotationView alloc] initWithAnnotation:annotation
                                                          reuseIdentifier:@"CustomAnnotationView"];
        }
       annotationView.image = [UIImage imageNamed:[self getAnnotationImageName:annotation]]; 
        // AMapAnnotation *amapAnnotation = (AMapAnnotation *)annotation;
        // annotationView.image = amapAnnotation.annotationImage == nil ? [UIImage imageNamed: @"location_traffic"] : [UIImage imageWithData:[[NSData alloc] initWithBase64EncodedString:amapAnnotation.annotationImage options:NSDataBase64DecodingIgnoreUnknownCharacters]];
        return annotationView;
    }
    return nil;
}

- (void)mapView:(MAMapView *)mapView didSelectAnnotationView:(MAAnnotationView *)view
{
    if ([view.annotation isKindOfClass:[AMapAnnotation class]] && hasListeners) {
        view.image = [UIImage imageNamed:@"location_selected"];
        [view setSelected:YES animated:YES];
        AMapAnnotation *annotation = (AMapAnnotation *)(view.annotation);
        [self sendEventWithName:@"EventAnnotationSelect" body:@{@"id": [NSNumber numberWithInt:annotation.annotationId], @"type": [NSString stringWithString:annotation.annotationType], @"longitude": [NSNumber numberWithDouble:annotation.coordinate.longitude], @"latitude": [NSNumber numberWithDouble:annotation.coordinate.latitude]}];
    }
}

- (void)mapView:(MAMapView *)mapView didDeselectAnnotationView:(MAAnnotationView *)view
{
    if ([view.annotation isKindOfClass:[AMapAnnotation class]] && hasListeners) {
        view.image = [UIImage imageNamed:[self getAnnotationImageName:view.annotation]];
        [view setSelected:NO animated:YES];
        AMapAnnotation *annotation = (AMapAnnotation *)(view.annotation);
        [self sendEventWithName:@"EventAnnotationDeselect" body:@{@"id": [NSNumber numberWithInt:annotation.annotationId]}];
    }
}

- (NSString*) getAnnotationImageName:(id<MAAnnotation>)annotation
{
    if ([annotation isKindOfClass:[AMapAnnotation class]]) {
        AMapAnnotation *aMapAnnotation = (AMapAnnotation*)annotation;
        if ([aMapAnnotation.annotationType isEqualToString:@"car_care"]) {
            return @"location_car_care";
        } else if ([aMapAnnotation.annotationType isEqualToString:@"car_wash"]) {
            return @"location_car_wash";
        } else if ([aMapAnnotation.annotationType isEqualToString:@"car_mall"]) {
            return @"location_car_mall";
        } else if ([aMapAnnotation.annotationType isEqualToString:@"car_oil"]) {
            return @"location_car_oil";
        } else if ([aMapAnnotation.annotationType isEqualToString:@"car_park"]) {
            return @"location_car_park";
        } else if ([aMapAnnotation.annotationType isEqualToString:@"offence_high"]) {
            return @"location_offence_high";
        } else if ([aMapAnnotation.annotationType isEqualToString:@"offence_high_stop"]) {
            return @"location_offence_high_stop";
        } else {
            return @"location_traffic";
        }
    }
    return @"location_traffic";
}

@end

==> react-native-wonder-amap-0.0.33.tgz: package/lib/ios/AMapEventEmitter.m <==
//
//  AMapEventDelegation.m
//  RCTAMap
//
//  Created by 王继荣 on 07/08/2017.
//  Copyright © 2017 cn.wonderbear. All rights reserved.
//

#import "AMapEventEmitter.h"

@interface AMapEventEmitter ()
{
    bool hasListeners;
}

@end

static AMapEventEmitter *sharedInstance;

@implementation AMapEventEmitter

RCT_EXPORT_MODULE()

+ (id)allocWithZone:(struct _NSZone *)zone
{
    static dispatch_once_t onceToken;
    dispatch_once(&onceToken, ^{
        sharedInstance = [super allocWithZone:zone];
    });
    return sharedInstance;
}

+ (instancetype)sharedInstance
{
    static dispatch_once_t onceToken;
    dispatch_once(&onceToken, ^{
        sharedInstance = [self new];
    });
    return sharedInstance;
}

- (id)copyWithZone:(NSZone *)zone
{
    return sharedInstance;
}

#pragma mark - RCTEventEmitter

- (NSArray<NSString *> *)supportedEvents
{
    return @[@"EventMapLoaded", @"EventAnnotationSelect", @"EventAnnotationDeselect"];
}

- (void)startObserving {
    hasListeners = YES;
}

- (void)stopObserving {
    hasListeners = NO;
}

#pragma mark - MAMapViewDelegate

- (void)mapInitComplete:(MAMapView *)mapView
{
    [self sendEventWithName:@"EventMapLoaded" body:[NSNumber numberWithBool:true]];
}

- (MAAnnotationView *)mapView:(MAMapView *)mapView viewForAnnotation:(id<MAAnnotation>)annotation
{
    if ([annotation isKindOfClass:[AMapAnnotation class]]) {
        MAAnnotationView *annotationView = (MAAnnotationView*)[mapView dequeueReusableAnnotationViewWithIdentifier:@"CustomAnnotationView"];
        if (!annotationView){
            annotationView = [[MAAnnotationView alloc] initWithAnnotation:annotation
                                                          reuseIdentifier:@"CustomAnnotationView"];
        }
       annotationView.image = [UIImage imageNamed:[self getAnnotationImageName:annotation]]; 
        // AMapAnnotation *amapAnnotation = (AMapAnnotation *)annotation;
        // annotationView.image = amapAnnotation.annotationImage == nil ? [UIImage imageNamed: @"location_traffic"] : [UIImage imageWithData:[[NSData alloc] initWithBase64EncodedString:amapAnnotation.annotationImage options:NSDataBase64DecodingIgnoreUnknownCharacters]];
        return annotationView;
    }
    return nil;
}

- (void)mapView:(MAMapView *)mapView didSelectAnnotationView:(MAAnnotationView *)view
{
    if ([view.annotation isKindOfClass:[AMapAnnotation class]] && hasListeners) {
        view.image = [UIImage imageNamed:@"location_selected"];
        [view setSelected:YES animated:YES];
        AMapAnnotation *annotation = (AMapAnnotation *)(view.annotation);
        [self sendEventWithName:@"EventAnnotationSelect" body:@{@"id": [NSNumber numberWithInt:annotation.annotationId], @"type": [NSString stringWithString:annotation.annotationType], @"longitude": [NSNumber numberWithDouble:annotation.coordinate.longitude], @"latitude": [NSNumber numberWithDouble:annotation.coordinate.latitude]}];
    }
}

- (void)mapView:(MAMapView *)mapView didDeselectAnnotationView:(MAAnnotationView *)view
{
    if ([view.annotation isKindOfClass:[AMapAnnotation class]] && hasListeners) {
        view.image = [UIImage imageNamed:[self getAnnotationImageName:view.annotation]];
        [view setSelected:NO animated:YES];
        AMapAnnotation *annotation = (AMapAnnotation *)(view.annotation);
        [self sendEventWithName:@"EventAnnotationDeselect" body:@{@"id": [NSNumber numberWithInt:annotation.annotationId]}];
    }
}

- (NSString*) getAnnotationImageName:(id<MAAnnotation>)annotation
{
    if ([annotation isKindOfClass:[AMapAnnotation class]]) {
        AMapAnnotation *aMapAnnotation = (AMapAnnotation*)annotation;
        if ([aMapAnnotation.annotationType isEqualToString:@"car_care"]) {
            return @"location_car_care";
        } else if ([aMapAnnotation.annotationType isEqualToString:@"car_wash"]) {
            return @"location_car_wash";
        } else if ([aMapAnnotation.annotationType isEqualToString:@"car_mall"]) {
            return @"location_car_mall";
        } else if ([aMapAnnotation.annotationType isEqualToString:@"car_oil"]) {
            return @"location_car_oil";
        } else if ([aMapAnnotation.annotationType isEqualToString:@"car_park"]) {
            return @"location_car_park";
        } else if ([aMapAnnotation.annotationType isEqualToString:@"offence_high"]) {
            return @"location_offence_high";
        } else if ([aMapAnnotation.annotationType isEqualToString:@"offence_high_stop"]) {
            return @"location_offence_high_stop";
        } else {
            return @"location_traffic";
        }
    }
    return @"location_traffic";
}

@end
